@@ -1,6 +1,6 @@
 package Lemonldap::NG::Manager::Api::2F;
 
-our $VERSION = '2.0.10';
+our $VERSION = '2.17.0';
 
 package Lemonldap::NG::Manager::Api;
 
@@ -10,7 +10,7 @@ use Mouse;
 use JSON;
 
 use Lemonldap::NG::Common::Session;
-use Lemonldap::NG::Common::Util qw/genId2F/;
+use Lemonldap::NG::Common::Util qw/genId2F display2F/;
 
 sub getSecondFactors {
     my ( $self, $req ) = @_;
@@ -139,11 +139,6 @@ sub _get2F {
     my ( $self, $uid, $type, $id ) = @_;
     my ( $res, $psessions, @secondFactors );
 
-    if ( defined $type ) {
-        $res = $self->_checkType($type);
-        return $res if ( $res->{res} ne 'ok' );
-    }
-
     $psessions = $self->_getSessions2F( $self->_getPersistentMod, 'Persistent',
         '_session_uid', $uid );
 
@@ -235,7 +230,7 @@ sub _delete2FFromSessions {
                     push @keep, $element;
                 }
                 else {
-                    $removed->{ genId2F($element) } = "removed";
+                    $removed->{ genId2F($element) } = $element;
                 }
             }
             if ( ( $total - scalar @keep ) > 0 ) {
@@ -279,10 +274,6 @@ sub _delete2FFromSessions {
 sub _delete2F {
     my ( $self, $uid, $type, $id ) = @_;
     my ( $res, $removed, $count );
-    if ( defined $type ) {
-        $res = $self->_checkType($type);
-        return $res if ( $res->{res} ne 'ok' );
-    }
 
     $res =
       $self->_delete2FFromSessions( $uid, $type, $id, $self->_getPersistentMod,
@@ -300,6 +291,13 @@ sub _delete2F {
     # merge results
     $removed = { %$removed, %{ $res->{removed} } };
     $count   = scalar( keys %$removed );
+    if ($count) {
+        my $list_log = join(
+            ",", map { display2F( $removed->{$_} ) }
+              keys %$removed
+        );
+        $self->userLogger->notice("[API] 2FA deletion for $uid: $list_log");
+    }
 
     return {
         res     => 'ok',
@@ -331,18 +329,4 @@ sub _getDevicesFromSessionData {
     return [];
 }
 
-sub _checkType {
-    my ( $self, $type ) = @_;
-
-    return {
-        res  => "ko",
-        code => 400,
-        msg  =>
-"Invalid input: Type \"$type\" does not exist. Allowed values for type are: \"U2F\", \"TOTP\", \"WebAuthn\" or \"UBK\""
-      }
-      unless ( $type =~ /\b(?:U2F|TOTP|UBK|WebAuthn)\b/i );
-
-    return { res => "ok" };
-}
-
 1;
