@@ -24,13 +24,14 @@ extends qw(
   Lemonldap::NG::Common::Conf::RESTServer
 );
 
-our $VERSION = '2.17.0';
+our $VERSION = '2.18.0';
 
 #############################
 # I. INITIALIZATION METHODS #
 #############################
 
 use constant defaultRoute => 'manager.html';
+use constant icon         => 'cog';
 
 has defaultNewKeySize => ( is => 'rw', default => 2048, );
 
@@ -68,6 +69,7 @@ sub init {
         confs => {
             newRSAKey      => 'newRSAKey',
             newCertificate => 'newCertificate',
+            newEcKeys      => 'newEcKeys',
             sendTestMail   => 'sendTestMail',
             raw            => 'newRawConf',
             '*'            => 'newConf'
@@ -157,6 +159,30 @@ sub newRSAKey {
     return $self->sendJSONresponse( $req, $keys );
 }
 
+# 35 - New EC key pair on demand
+#      --------------------------
+
+##@method public PSGI-JSON-response newEcKeys($req)
+# Return a hashref containing private and public keys
+#
+#@param $req Lemonldap::NG::Common::PSGI::Request object
+#@return PSGI JSON response
+sub newEcKeys {
+    my ( $self, $req, @others ) = @_;
+    require Crypt::PK::ECC;
+    my $ec_key = Crypt::PK::ECC->new();
+    $ec_key->generate_key('secp256r1');
+
+    my $pubKey = $ec_key->export_key_pem('public');
+    my $privKey = $ec_key->export_key_pem('private');
+    my $keys = {
+        private => $privKey,
+        public => $pubKey,
+        hash => md5_base64($pubKey),
+    };
+    return $self->sendJSONresponse( $req, $keys );
+}
+
 # This function does the dirty X509 work,
 # mostly copied from IO::Socket::SSL::Utils
 # and adapter to work on old platforms (CentOS7)
