@@ -5,7 +5,7 @@ use Mouse;
 use Lemonldap::NG::Manager::Conf::Parser;
 use Lemonldap::NG::Common::Conf::Constants;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.8';
 
 *defaultValue = \&Lemonldap::NG::Manager::Conf::Parser::defaultValue;
 
@@ -20,9 +20,10 @@ sub diff {
                 $res[$i]->{$key} = $tmp[$i] if ( $tmp[$i] );
             }
         }
-        elsif ( $key =~ $hashParameters
-            or
-            ( ref( $conf[0]->{$key} ) and ref( $conf[0]->{$key} ) eq 'HASH' ) )
+        elsif (
+            $key =~ $hashParameters
+            or ( ref( $conf[0]->{$key} ) and ref( $conf[0]->{$key} ) eq 'HASH' )
+          )
         {
             if ( ref $conf[1]->{$key} ) {
                 my @tmp =
@@ -90,10 +91,8 @@ sub diff {
     while ( my $key = shift @{ $keys[1] } ) {
         next unless ( defined( $conf[1]->{$key} ) );
         next if ( $key =~ $hashParameters and not( %{ $conf[1]->{$key} } ) );
-        if (
-            (
-                not ref( $conf[1]->{$key} ) and not(
-                    (
+        if ( (
+                not ref( $conf[1]->{$key} ) and not( (
                         defined defaultValue( $self, $key )
                         and $conf[1]->{$key} eq defaultValue( $self, $key )
                     )
@@ -112,8 +111,8 @@ sub appListDiff {
     my ( $self, @conf ) = @_;
     my @res;
     my @keys = (
-        [ sort grep { $_ !~ /^(?:catname|type)$/ } keys %{ $conf[0] } ],
-        [ sort grep { $_ !~ /^(?:catname|type)$/ } keys %{ $conf[1] } ]
+        [ sort grep { $_ !~ /^(?:catname|type|order)$/ } keys %{ $conf[0] } ],
+        [ sort grep { $_ !~ /^(?:catname|type|order)$/ } keys %{ $conf[1] } ]
     );
     while ( my $key = shift @{ $keys[0] } ) {
 
@@ -204,7 +203,7 @@ sub _copyAppList {
     my ( $self, $conf ) = @_;
     my %res;
     if ( $conf->{type} eq 'category' ) {
-        foreach ( grep { $_ !~ /^(?:catname|type)$/ } keys %$conf ) {
+        foreach ( grep { $_ !~ /^(?:catname|type|order)$/ } keys %$conf ) {
             my @tmp = _copyAppList( $self, $conf->{$_} );
             $res{ $tmp[0] } = $tmp[1];
         }
