@@ -363,6 +363,14 @@ function templates(tpl,key) {
                      {
                         "k" : "client_secret_basic",
                         "v" : "client_secret_basic"
+                     },
+                     {
+                        "k" : "client_secret_jwt",
+                        "v" : "client_secret_jwt"
+                     },
+                     {
+                        "k" : "private_key_jwt",
+                        "v" : "private_key_jwt"
                      }
                   ],
                   "title" : "oidcOPMetaDataOptionsTokenEndpointAuthMethod",
@@ -469,6 +477,34 @@ function templates(tpl,key) {
             "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRedirectUris",
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRedirectUris",
             "title" : "oidcRPMetaDataOptionsRedirectUris"
+         },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthMethod",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthMethod",
+            "select" : [
+               {
+                  "k" : "",
+                  "v" : "Any"
+               },
+               {
+                  "k" : "client_secret_post",
+                  "v" : "client_secret_post"
+               },
+               {
+                  "k" : "client_secret_basic",
+                  "v" : "client_secret_basic"
+               },
+               {
+                  "k" : "client_secret_jwt",
+                  "v" : "client_secret_jwt"
+               },
+               {
+                  "k" : "private_key_jwt",
+                  "v" : "private_key_jwt"
+               }
+            ],
+            "title" : "oidcRPMetaDataOptionsAuthMethod",
+            "type" : "select"
          }
       ],
       "help" : "idpopenidconnect.html#basic-options",
@@ -625,6 +661,34 @@ function templates(tpl,key) {
                      {
                         "k" : "RS512",
                         "v" : "RS512"
+                     },
+                     {
+                        "k" : "PS256",
+                        "v" : "PS256"
+                     },
+                     {
+                        "k" : "PS384",
+                        "v" : "PS384"
+                     },
+                     {
+                        "k" : "PS512",
+                        "v" : "PS512"
+                     },
+                     {
+                        "k" : "ES256",
+                        "v" : "ES256"
+                     },
+                     {
+                        "k" : "ES384",
+                        "v" : "ES384"
+                     },
+                     {
+                        "k" : "ES512",
+                        "v" : "ES512"
+                     },
+                     {
+                        "k" : "EdDSA",
+                        "v" : "EdDSA"
                      }
                   ],
                   "title" : "oidcRPMetaDataOptionsIDTokenSignAlg",
@@ -635,6 +699,18 @@ function templates(tpl,key) {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenSignAlg",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenSignAlg",
                   "select" : [
+                     {
+                        "k" : "HS256",
+                        "v" : "HS256"
+                     },
+                     {
+                        "k" : "HS384",
+                        "v" : "HS384"
+                     },
+                     {
+                        "k" : "HS512",
+                        "v" : "HS512"
+                     },
                      {
                         "k" : "RS256",
                         "v" : "RS256"
@@ -646,6 +722,34 @@ function templates(tpl,key) {
                      {
                         "k" : "RS512",
                         "v" : "RS512"
+                     },
+                     {
+                        "k" : "PS256",
+                        "v" : "PS256"
+                     },
+                     {
+                        "k" : "PS384",
+                        "v" : "PS384"
+                     },
+                     {
+                        "k" : "PS512",
+                        "v" : "PS512"
+                     },
+                     {
+                        "k" : "ES256",
+                        "v" : "ES256"
+                     },
+                     {
+                        "k" : "ES384",
+                        "v" : "ES384"
+                     },
+                     {
+                        "k" : "ES512",
+                        "v" : "ES512"
+                     },
+                     {
+                        "k" : "EdDSA",
+                        "v" : "EdDSA"
                      }
                   ],
                   "title" : "oidcRPMetaDataOptionsAccessTokenSignAlg",
@@ -687,6 +791,34 @@ function templates(tpl,key) {
                      {
                         "k" : "RS512",
                         "v" : "JWT/RS512"
+                     },
+                     {
+                        "k" : "PS256",
+                        "v" : "JWT/PS256"
+                     },
+                     {
+                        "k" : "PS384",
+                        "v" : "JWT/PS384"
+                     },
+                     {
+                        "k" : "PS512",
+                        "v" : "JWT/PS512"
+                     },
+                     {
+                        "k" : "ES256",
+                        "v" : "JWT/ES256"
+                     },
+                     {
+                        "k" : "ES384",
+                        "v" : "JWT/ES384"
+                     },
+                     {
+                        "k" : "ES512",
+                        "v" : "JWT/ES512"
+                     },
+                     {
+                        "k" : "EdDSA",
+                        "v" : "JWT/EdDSA"
                      }
                   ],
                   "title" : "oidcRPMetaDataOptionsUserInfoSignAlg",
@@ -720,6 +852,11 @@ function templates(tpl,key) {
                   "title" : "oidcRPMetaDataOptionsAllowClientCredentialsGrant",
                   "type" : "bool"
                },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRequestUris",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRequestUris",
+                  "title" : "oidcRPMetaDataOptionsRequestUris"
+               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnLevel",
@@ -730,12 +867,322 @@ function templates(tpl,key) {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRule",
                   "title" : "oidcRPMetaDataOptionsRule"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenEncKeyMgtAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenEncKeyMgtAlg",
+                  "select" : [
+                     {
+                        "k" : "",
+                        "v" : "None"
+                     },
+                     {
+                        "k" : "RSA-OAEP",
+                        "v" : "RSA-OAEP"
+                     },
+                     {
+                        "k" : "RSA-OAEP-256",
+                        "v" : "RSA-OAEP-256"
+                     },
+                     {
+                        "k" : "RSA1_5",
+                        "v" : "RSA1_5"
+                     },
+                     {
+                        "k" : "ECDH-ES",
+                        "v" : "ECDH-ES"
+                     },
+                     {
+                        "k" : "ECDH-ES+A128KW",
+                        "v" : "ECDH-ES+A128KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A192KW",
+                        "v" : "ECDH-ES+A192KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A256KW",
+                        "v" : "ECDH-ES+A256KW"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsAccessTokenEncKeyMgtAlg",
+                  "type" : "select"
+               },
+               {
+                  "default" : "A256GCM",
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenEncContentEncAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAccessTokenEncContentEncAlg",
+                  "select" : [
+                     {
+                        "k" : "A256CBC-HS512",
+                        "v" : "A256CBC-HS512"
+                     },
+                     {
+                        "k" : "A256GCM",
+                        "v" : "A256GCM"
+                     },
+                     {
+                        "k" : "A192CBC-HS384",
+                        "v" : "A192CBC-HS384"
+                     },
+                     {
+                        "k" : "A192GCM",
+                        "v" : "A192GCM"
+                     },
+                     {
+                        "k" : "A128CBC-HS256",
+                        "v" : "A128CBC-HS256"
+                     },
+                     {
+                        "k" : "A128GCM",
+                        "v" : "A128GCM"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsAccessTokenEncContentEncAlg",
+                  "type" : "select"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIdTokenEncKeyMgtAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIdTokenEncKeyMgtAlg",
+                  "select" : [
+                     {
+                        "k" : "",
+                        "v" : "None"
+                     },
+                     {
+                        "k" : "RSA-OAEP",
+                        "v" : "RSA-OAEP"
+                     },
+                     {
+                        "k" : "RSA-OAEP-256",
+                        "v" : "RSA-OAEP-256"
+                     },
+                     {
+                        "k" : "RSA1_5",
+                        "v" : "RSA1_5"
+                     },
+                     {
+                        "k" : "ECDH-ES",
+                        "v" : "ECDH-ES"
+                     },
+                     {
+                        "k" : "ECDH-ES+A128KW",
+                        "v" : "ECDH-ES+A128KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A192KW",
+                        "v" : "ECDH-ES+A192KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A256KW",
+                        "v" : "ECDH-ES+A256KW"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsIdTokenEncKeyMgtAlg",
+                  "type" : "select"
+               },
+               {
+                  "default" : "A256GCM",
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIdTokenEncContentEncAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsIdTokenEncContentEncAlg",
+                  "select" : [
+                     {
+                        "k" : "A256CBC-HS512",
+                        "v" : "A256CBC-HS512"
+                     },
+                     {
+                        "k" : "A256GCM",
+                        "v" : "A256GCM"
+                     },
+                     {
+                        "k" : "A192CBC-HS384",
+                        "v" : "A192CBC-HS384"
+                     },
+                     {
+                        "k" : "A192GCM",
+                        "v" : "A192GCM"
+                     },
+                     {
+                        "k" : "A128CBC-HS256",
+                        "v" : "A128CBC-HS256"
+                     },
+                     {
+                        "k" : "A128GCM",
+                        "v" : "A128GCM"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsIdTokenEncContentEncAlg",
+                  "type" : "select"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserInfoEncKeyMgtAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserInfoEncKeyMgtAlg",
+                  "select" : [
+                     {
+                        "k" : "",
+                        "v" : "None"
+                     },
+                     {
+                        "k" : "RSA-OAEP",
+                        "v" : "RSA-OAEP"
+                     },
+                     {
+                        "k" : "RSA-OAEP-256",
+                        "v" : "RSA-OAEP-256"
+                     },
+                     {
+                        "k" : "RSA1_5",
+                        "v" : "RSA1_5"
+                     },
+                     {
+                        "k" : "ECDH-ES",
+                        "v" : "ECDH-ES"
+                     },
+                     {
+                        "k" : "ECDH-ES+A128KW",
+                        "v" : "ECDH-ES+A128KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A192KW",
+                        "v" : "ECDH-ES+A192KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A256KW",
+                        "v" : "ECDH-ES+A256KW"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsUserInfoEncKeyMgtAlg",
+                  "type" : "select"
+               },
+               {
+                  "default" : "A256GCM",
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserInfoEncContentEncAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserInfoEncContentEncAlg",
+                  "select" : [
+                     {
+                        "k" : "A256CBC-HS512",
+                        "v" : "A256CBC-HS512"
+                     },
+                     {
+                        "k" : "A256GCM",
+                        "v" : "A256GCM"
+                     },
+                     {
+                        "k" : "A192CBC-HS384",
+                        "v" : "A192CBC-HS384"
+                     },
+                     {
+                        "k" : "A192GCM",
+                        "v" : "A192GCM"
+                     },
+                     {
+                        "k" : "A128CBC-HS256",
+                        "v" : "A128CBC-HS256"
+                     },
+                     {
+                        "k" : "A128GCM",
+                        "v" : "A128GCM"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsUserInfoEncContentEncAlg",
+                  "type" : "select"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutEncKeyMgtAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutEncKeyMgtAlg",
+                  "select" : [
+                     {
+                        "k" : "",
+                        "v" : "None"
+                     },
+                     {
+                        "k" : "RSA-OAEP",
+                        "v" : "RSA-OAEP"
+                     },
+                     {
+                        "k" : "RSA-OAEP-256",
+                        "v" : "RSA-OAEP-256"
+                     },
+                     {
+                        "k" : "RSA1_5",
+                        "v" : "RSA1_5"
+                     },
+                     {
+                        "k" : "ECDH-ES",
+                        "v" : "ECDH-ES"
+                     },
+                     {
+                        "k" : "ECDH-ES+A128KW",
+                        "v" : "ECDH-ES+A128KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A192KW",
+                        "v" : "ECDH-ES+A192KW"
+                     },
+                     {
+                        "k" : "ECDH-ES+A256KW",
+                        "v" : "ECDH-ES+A256KW"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsLogoutEncKeyMgtAlg",
+                  "type" : "select"
+               },
+               {
+                  "default" : "A256GCM",
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutEncContentEncAlg",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsLogoutEncContentEncAlg",
+                  "select" : [
+                     {
+                        "k" : "A256CBC-HS512",
+                        "v" : "A256CBC-HS512"
+                     },
+                     {
+                        "k" : "A256GCM",
+                        "v" : "A256GCM"
+                     },
+                     {
+                        "k" : "A192CBC-HS384",
+                        "v" : "A192CBC-HS384"
+                     },
+                     {
+                        "k" : "A192GCM",
+                        "v" : "A192GCM"
+                     },
+                     {
+                        "k" : "A128CBC-HS256",
+                        "v" : "A128CBC-HS256"
+                     },
+                     {
+                        "k" : "A128GCM",
+                        "v" : "A128GCM"
+                     }
+                  ],
+                  "title" : "oidcRPMetaDataOptionsLogoutEncContentEncAlg",
+                  "type" : "select"
                }
             ],
             "id" : "security",
             "title" : "security",
             "type" : "simpleInputContainer"
          },
+         {
+            "_nodes" : [
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsJwksUri",
+                  "help" : "idpopenidconnect.html",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsJwksUri",
+                  "title" : "oidcRPMetaDataOptionsJwksUri"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsJwks",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsJwks",
+                  "title" : "oidcRPMetaDataOptionsJwks",
+                  "type" : "file"
+               }
+            ],
+            "id" : "keys",
+            "title" : "keys"
+         },
          {
             "_nodes" : [
                {
